@@ -1,22 +1,22 @@
 package Google::RestApi::DriveApi3;
 
-our $VERSION = '1.0.4';
+our $VERSION = '1.0.5';
 
 use Google::RestApi::Setup;
 
+use Readonly;
+use URI;
+
 use aliased 'Google::RestApi::DriveApi3::File';
 
-# TODO: switch to ReadOnly
-use constant {
-  Drive_Endpoint => "https://www.googleapis.com/drive/v3",
-  Drive_File_Id  => "[a-zA-Z0-9-_]+",
-};
+Readonly our $Drive_Endpoint => 'https://www.googleapis.com/drive/v3';
+Readonly our $Drive_File_Id  => '[a-zA-Z0-9-_]+';
 
 sub new {
   my $class = shift;
   state $check = compile_named(
     api      => HasApi,
-    endpoint => Str, { default => Drive_Endpoint },
+    endpoint => Str, { default => $Drive_Endpoint },
   );
   return bless $check->(@_), $class;
 }
@@ -33,13 +33,28 @@ sub api {
   return $self->{api}->api(%$p, uri => $uri);
 }
 
-sub filter_files {
+sub list {
   my $self = shift;
   state $check = compile(Str, HashRef, { default => {} });
   my ($filter, $params) = $check->(@_);
-  $params->{'q'} = $filter;
-  return $self->api(params => $params, uri => 'files');
+
+  $params->{q} = $filter;
+  $params->{fields} = 'files(id, name)' unless $params->{fields};
+  $params->{fields} = 'nextPageToken, ' . $params->{fields};
+
+  my @list;
+  my $next_page_token;
+  do {
+    $params->{pageToken} = $next_page_token if $next_page_token;
+    my $result = $self->api(uri => 'files', params => $params);
+    push(@list, $result->{files}->@*) if $result->{files};
+    $next_page_token = $result->{nextPageToken};
+  } until !$next_page_token;
+
+  return @list;
 }
+# backward compatibility.
+*filter_files = *list{CODE};
 
 sub upload_endpoint {
   my $self = shift;
@@ -77,6 +92,6 @@ Robin Murray mvsjes@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2021, Robin Murray. All rights reserved.
+Copyright (c) 2019-2026 Robin Murray. All rights reserved.
 
 This program is free software; you may redistribute it and/or modify it under the same terms as Perl itself.
