@@ -1,33 +1,31 @@
 package Google::RestApi::SheetsApi4;
 
-our $VERSION = '1.0.4';
+our $VERSION = '1.0.5';
 
 use Google::RestApi::Setup;
 
 use Module::Load qw( load );
+use Readonly;
 use Try::Tiny ();
 use YAML::Any ();
 
 use aliased 'Google::RestApi::DriveApi3';
 use aliased 'Google::RestApi::SheetsApi4::Spreadsheet';
 
-# TODO: switch to ReadOnly
-use constant {
-  Sheets_Endpoint    => "https://sheets.googleapis.com/v4/spreadsheets",
-  Spreadsheet_Filter => "mimeType='application/vnd.google-apps.spreadsheet'",
-  Spreadsheet_Id     => DriveApi3->Drive_File_Id,
-  Spreadsheet_Uri    => "https://docs.google.com/spreadsheets/d",
-  Worksheet_Id       => "[0-9]+",
-  Worksheet_Uri      => "[#&]gid=([0-9]+)",
-};
+Readonly our $Sheets_Endpoint    => "https://sheets.googleapis.com/v4/spreadsheets";
+Readonly our $Spreadsheet_Id     => $Google::RestApi::DriveApi3::Drive_File_Id;
+Readonly our $Spreadsheet_Uri    => "https://docs.google.com/spreadsheets/d";
+Readonly our $Worksheet_Id       => "[0-9]+";
+Readonly our $Worksheet_Uri      => "[#&]gid=([0-9]+)";
+Readonly our $Spreadsheet_Filter => "mimeType = 'application/vnd.google-apps.spreadsheet'";
 
 sub new {
   my $class = shift;
 
   state $check = compile_named(
     api           => HasApi,                                           # the G::RestApi object that will be used to send http calls.
-    drive         => HasMethods[qw(filter_files)], { optional => 1 },  # a drive instnace, could be your own, defaults to G::R::DriveApi3.
-    endpoint      => Str, { default => Sheets_Endpoint },              # this gets tacked on to the api uri to reach the sheets endpoint.
+    drive         => HasMethods[qw(list)], { optional => 1 },  # a drive instnace, could be your own, defaults to G::R::DriveApi3.
+    endpoint      => Str, { default => $Sheets_Endpoint },              # this gets tacked on to the api uri to reach the sheets endpoint.
   );
   my $self = $check->(@_);
 
@@ -79,7 +77,7 @@ sub create_spreadsheet {
 
 sub copy_spreadsheet {
   my $self = shift;
-  my $id = Spreadsheet_Id;
+  my $id = $Spreadsheet_Id;
   state $check = compile_named(
     spreadsheet_id => StrMatch[qr/$id/],
     _extra_        => slurpy Any,
@@ -93,50 +91,64 @@ sub copy_spreadsheet {
 
 sub delete_spreadsheet {
   my $self = shift;
-  my $id = Spreadsheet_Id;
+  my $id = $Spreadsheet_Id;
   state $check = compile(StrMatch[qr/$id/]);
   my ($spreadsheet_id) = $check->(@_);
   return $self->drive()->file(id => $spreadsheet_id)->delete();
 }
 
-# delete all the spreadsheets by the names passed.
-sub delete_all_spreadsheets {
+sub delete_all_spreadsheets_by_filters {
   my $self = shift;
 
   state $check = compile(ArrayRef->plus_coercions(Str, sub { [$_]; }));
-  my ($names) = $check->(@_);
+  my ($filter) = $check->(@_);
 
   my $count = 0;
-  foreach my $name (@$names) {
-    my @spreadsheets = grep { $_->{name} eq $name; } $self->spreadsheets();
+  foreach my $filter (@$filter) {
+    my @spreadsheets = $self->spreadsheets_by_filter($filter);
     $count += scalar @spreadsheets;
-    DEBUG(sprintf("Deleting %d spreadsheets for name '$name'", scalar @spreadsheets));
+    DEBUG(sprintf("Deleting %d spreadsheets for filter '$filter'", scalar @spreadsheets));
     $self->delete_spreadsheet($_->{id}) foreach (@spreadsheets);
   }
   return $count;
 }
 
-# list all spreadsheets.
+sub delete_all_spreadsheets {
+  my $self = shift;
+  my @names = @_;
+  @names = map { "name = '$_"; } @names;
+  return $self->delete_all_spreadsheets_by_filters(@names);
+}
+
+sub spreadsheets_by_filter {
+  my $self = shift;
+
+  state $check = compile(Optional[Str]);
+  my ($extra_filter) = $check->(@_);
+
+  my $drive = $self->drive();
+  my $filter = $Spreadsheet_Filter;
+  $filter .= " and ($extra_filter)" if $extra_filter;
+  return $drive->list($filter);
+}
+
 sub spreadsheets {
   my $self = shift;
-  my $drive = $self->drive();
-  my $spreadsheets = $drive->filter_files(Spreadsheet_Filter);
-  my @spreadsheets = map { { id => $_->{id}, name => $_->{name} }; } @{ $spreadsheets->{files} };
-  return @spreadsheets;
+  my ($name) = @_;
+  $name = "name = '$name'" if $name;
+  return $self->spreadsheets_by_filter($name);
 }
 
 sub drive {
   my $self = shift;
-  if (!$self->{drive}) {
-    load DriveApi3;
-    $self->{drive} = DriveApi3->new(api => $self->rest_api());
-  }
+  $self->{drive} //= DriveApi3->new(api => $self->rest_api());
   return $self->{drive};
 }
 
 sub open_spreadsheet { Spreadsheet->new(sheets_api => shift, @_); }
 sub transaction { shift->rest_api()->transaction(); }
 sub stats { shift->rest_api()->stats(); }
+sub reset_stats { shift->rest_api->reset_stats(); }
 sub rest_api { shift->{api}; }
 
 1;
@@ -309,6 +321,8 @@ C<t/tutorial/sheets/*> also has a step-by-step tutorial of creating and updating
 
 =item * L<Google::RestApi::SheetsApi4::Range::Cell>
 
+=item * L<Google::RestApi::SheetsApi4::Range::Iterator>
+
 =item * L<Google::RestApi::SheetsApi4::RangeGroup>
 
 =item * L<Google::RestApi::SheetsApi4::RangeGroup::Iterator>
@@ -405,9 +419,9 @@ spreadsheet_id is the file ID in Google Drive of the spreadsheet you want to del
 
 Returns the Google API response.
 
-=item delete_all_spreadsheets(spreadsheet_name<string>);
+=item delete_all_spreadsheets_by_filters([spreadsheet_name<string>]);
 
-Deletes all spreadsheets with the given name from Google Drive. 
+Deletes all spreadsheets with the given names from Google Drive. 
 
 Returns the number of spreadsheets deleted.
 
@@ -444,6 +458,6 @@ Robin Murray mvsjes@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2021, Robin Murray. All rights reserved.
+Copyright (c) 2019-2026 Robin Murray. All rights reserved.
 
 This program is free software; you may redistribute it and/or modify it under the same terms as Perl itself.
