@@ -1,6 +1,6 @@
 package Google::RestApi::SheetsApi4::RangeGroup::Tie;
 
-our $VERSION = '1.0.4';
+our $VERSION = '1.0.5';
 
 use Google::RestApi::Setup;
 
@@ -120,7 +120,7 @@ sub STORE {
   if (!$self->ranges()->{$key}) {
     my $worksheet = $self->worksheet()
       or LOGDIE "No default worksheet provided for new range '$key'. Call default_worksheet() first.";    
-    my $tied = $worksheet->tie_ranges({ $key => $key });
+    my $tied = $worksheet->tie_ranges($key => $key);
     $self->add_tied($tied);
   }
 
@@ -244,6 +244,6 @@ Robin Murray mvsjes@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2021, Robin Murray. All rights reserved.
+Copyright (c) 2019-2026 Robin Murray. All rights reserved.
 
 This program is free software; you may redistribute it and/or modify it under the same terms as Perl itself.
